import { feature } from "topojson";
import {select,
        json,
        geoPath, 
        geoMercator,
        zoom,
        event} from "d3";

const svg = d3.select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');
const projection = geoMercator().scale(4000).translate([-5850, 2000])
const pathGenerator = geoPath().projection(projection);
const g= svg.append('g');
const TipsText = "Tips: Hover on any area to see details";
const HeaderText = "Poverty Map in Bangladesh";

svg.style('background-color',"white");
svg.append('text').attr('y',40).attr('x',300).text(HeaderText);
svg.append('text').attr('y',height-150).attr('x',width-280).text(TipsText).attr('class',"tips");
svg.call(zoom().on('zoom',()=>{
	console.log("Zooming..");
  g.attr('transform',event.transform);
}));


// Parsing Data
let count = 0;
Promise.all([
  json("salesData.json"),
	json("https://raw.githubusercontent.com/techslides/D3-Maps/master/data/world/country/Bangladesh.topo.json"),
  json("https://raw.githubusercontent.com/emon535/bangladesh-geojson/master/bangladesh.topo.json")
]).then(([salesData,topoJsonData,disTopoJsonData])=> {
  console.log(topoJsonData);
    // Get Sales information on hover
      const getSalesInformation =(d)=> {
        //console.log(d.properties.NAME_3, count++);
        const districtName = d.properties.NAME_3.replace(/\s/g, "").toUpperCase(); 
        let selectedDistrict = salesData.filter(obj => {
            return obj.name === districtName;
          // console.log(selectedDistrict);
        })
        //console.log(selectedDistrict);
        let outputString = `City: ${selectedDistrict[0].name}\nCity ID: ${selectedDistrict[0].id} \nExtreme Level: ${selectedDistrict[0].extreme} \nPoor Level: ${selectedDistrict[0].poor}`;  
        return outputString;
    }
       
      var myColor = d3.scaleLinear()
  						.range(["white", "red"])
              .domain([1,63.5]);
  
      const getColor =(d)=> {
        const districtName = d.properties.NAME_3.replace(/\s/g, "").toUpperCase(); 
        let distPoverty = salesData.filter(obj => {
            if( obj.name === districtName){
							return obj.poor;
            };
        })
       let povertyRate =distPoverty[0].poor;
       
       //console.log(myColor(povertyRate));
       return myColor(povertyRate); 
      }

    // Parsing feature from Data
    const subdistrict = feature(disTopoJsonData, disTopoJsonData.objects["bangladesh[1]"]);  
  	console.log(subdistrict)

    // Construct map path from feature data( subdistrict);
    const dist = g.selectAll('path').data(subdistrict.features).enter().append('path')
    				.style("fill", (d)=>getColor(d))
            .attr('class', 'district')
            .attr('d', pathGenerator);        
  	
  	dist.append('title').text((d)=>getSalesInformation(d));

});

